summaryrefslogtreecommitdiff
path: root/shaders/post/prefix.glsl
diff options
context:
space:
mode:
Diffstat (limited to 'shaders/post/prefix.glsl')
-rw-r--r--shaders/post/prefix.glsl11
1 files changed, 9 insertions, 2 deletions
diff --git a/shaders/post/prefix.glsl b/shaders/post/prefix.glsl
index efa49483..e718a98f 100644
--- a/shaders/post/prefix.glsl
+++ b/shaders/post/prefix.glsl
@@ -39,12 +39,19 @@ layout(set = 3, binding = 0, std140) uniform Globals {
uniform vec3 iSelectionBackgroundColor;
};
// pardes's own: 1 when the window is opaque, so a pass cannot punch holes
// in it through its alpha.
layout(set = 3, binding = 1, std140) uniform PardesPost {
float pardesOpaque;
+ float pardesLevel;
};
+// A bundled pass's constant at levels 1, 2 and 3.
+float pardesByLevel(float one, float two, float three) {
+ return pardesLevel < 1.5 ? one : (pardesLevel < 2.5 ? two : three);
+}
+
#define CURSORSTYLE_BLOCK 0
#define CURSORSTYLE_BLOCK_HOLLOW 1
#define CURSORSTYLE_BAR 2
@@ -39,12 +39,19 @@ layout(set = 3, binding = 0, std140) uniform Globals {
uniform vec3 iSelectionBackgroundColor;
};
-// pardes's own: 1 when the window is opaque, so a pass cannot punch holes
-// in it through its alpha.
+// pardes's own: pardesOpaque is 1 when the window is opaque, so a pass
+// cannot punch holes in it through its alpha; pardesLevel is a bundled
+// pass's strength, 1 to 3 (`Crt 3`), and 0 for a user's file.
layout(set = 3, binding = 1, std140) uniform PardesPost {
float pardesOpaque;